Learn R Programming

BNPTSclust (version 2.0)

diagplots: Diagnostic plots function.

Description

Function that produces the diagnostic plots to assess the convergence of the Markov Chains generated by either of the functions: "tseriesca", "tseriescm" or "tseriescq".

Usage

diagplots(L)

Arguments

L

output list from the functions: "tseriesca", "tseriescm" or "tseriescq".

Value

The function returns three different kinds of plots to assess convergence of the generated Markov Chain: trace plots, histograms and ergodic mean plots.

Details

See the examples in the documentation files of "tseriesca", "tseriescm" or "tseriescq" for an example of this function's usage.