Function that produces the diagnostic plots to assess the convergence of the Markov Chains generated by either of the functions: "tseriesca", "tseriescm" or "tseriescq".
diagplots(L)output list from the functions: "tseriesca", "tseriescm" or "tseriescq".
The function returns three different kinds of plots to assess convergence of the generated Markov Chain: trace plots, histograms and ergodic mean plots.
See the examples in the documentation files of "tseriesca", "tseriescm" or "tseriescq" for an example of this function's usage.